
var platform = require('../../platform', function(platform) {/*…*/});

console.log("platform.name = ", platform.name)
console.log("platform.version = ", platform.version)
console.log("platform.layout = ", platform.layout)
console.log("platform.os = ", platform.os)
console.log("platform.description = ", platform.description)
console.log("platform.product = ", platform.product)
console.log("platform.manufacturer = ", platform.manufacturer)

phantom.exit(0)
