
var platform = require('../../platform', function(platform) {/*…*/});

java.lang.System.out.print("platform.name = ")
java.lang.System.out.println(platform.name ? platform.name : "null")
java.lang.System.out.print("platform.version = ")
java.lang.System.out.println(platform.version ? platform.version : "null")
java.lang.System.out.print("platform.layout = ")
java.lang.System.out.println(platform.layout ? platform.layout : "null")
java.lang.System.out.print("platform.os = ")
java.lang.System.out.println(platform.os ? platform.os : "null")
java.lang.System.out.print("platform.description = ")
java.lang.System.out.println(platform.description ? platform.description : "null")
java.lang.System.out.print("platform.product = ")
java.lang.System.out.println(platform.product ? platform.product : "null")
java.lang.System.out.print("platform.manufacturer = ")
java.lang.System.out.println(platform.manufacturer ? platform.manufacturer : "null")

